@@ -61,14 +61,14 @@ class Client(object):
     # csv
     def get_csv(self, absolute_path):
         return self._get_csv_wrapper(absolute_path).to_list()
-    def get_pandas_csv(self, absolute_path):
-        return self._get_csv_wrapper(absolute_path).to_pandas()
+    def get_pandas_csv(self, absolute_path, *args, **kwargs):
+        return self._get_csv_wrapper(absolute_path).to_pandas(*args, **kwargs)
 
     # json
     def get_json(self, absolute_path):
         return self._get_json_wrapper(absolute_path).to_json()
-    def get_pandas_json(self, absolute_path):
-        return self._get_json_wrapper(absolute_path).to_pandas()
+    def get_pandas_json(self, absolute_path, *args, **kwargs):
+        return self._get_json_wrapper(absolute_path).to_pandas(*args, **kwargs)
     
     # image
     def get_pil_image(self, absolute_path):
