@@ -17,8 +17,8 @@ class JsonWrapper(object):
     def to_json(self):
         return json.loads(self.content_text.replace("'", '"'))
     def to_pandas(self, *args, **kwargs):
-        return pandas.read_csv(
-            filepath_or_buffer=StringIO(self.content_text),
+        return pandas.read_json(
+            path_or_buf=StringIO(self.content_text),
             *args,
             **kwargs
         )
\ No newline at end of file
